==> typist-0.3.0.tar.gz: typist-0.3.0/typist/client.py <==
"""Client for django-secretary."""
import json
from typing import Callable, Sequence, Set, Tuple, Union
from urllib.parse import urljoin
from uuid import UUID

import requests
from requests import HTTPError, RequestException, Response

from typist import rest


class TemplateNotFound(ValueError):
    """Template not found exception."""


def process_errors(func: Callable[..., Response]) -> Callable[..., Response]:
    """
    Process commonly raised connection errors.

    Args:
        func: Function returning the requests Response object.

    Raises:
        TemplateNotFound: If response status code is 404.
        ValueError: In case of any other HTTP error (such as 403 or 500).
        RuntimeError: In case of any other error (such as ConnectionError).
    """
    def wrapper(*args, **kwargs) -> Response:
        try:
            response = func(*args, **kwargs)
            if response.status_code == 404:
                raise TemplateNotFound('Template not found at url: {}'.format(response.request.url))
            response.raise_for_status()
        except HTTPError as error:
            if response.status_code >= 400 and response.status_code < 500:
                raise ValueError(str(error))
            else:
                raise RuntimeError(str(error))
        except RequestException as error:
            raise RuntimeError(str(error))

        return response

    return wrapper


class SecretaryClient:
    """Client for django-secretary."""

    def __init__(self, server_url: str, timeout: Union[float, Tuple[float, float]] = 3.05):
        """
        Initialize REST API client.

        Args:
            server_url: Server url of django-secretary app, including the path to the REST API with trailing slash.
            timeout: Timeout for the django-secretary API.
        """
        self.server_url = server_url
        self.timeout = timeout

    def render(self, template: Union[UUID, str], context: dict) -> str:
        """
        Render plaintext template.

        Args:
            template: Name of template or UUID.
            context: Context passed to template for rendering.

        Returns:
            Rendered plain text template.

        Raises:
            TemplateNotFound: If response status code is 404.
            ValueError: In case of any other HTTP error (such as 403 or 500).
            RuntimeError: In case of any other error (such as ConnectionError).
        """
        response = self._get_render_response(template, context, accept='text/plain')
        return response.text

    def render_html(self, template: Union[UUID, str], context: dict) -> str:
        """
        Render HTML template.

        Args:
            template: Name of template or UUID.
            context: Context passed to template for rendering.

        Returns:
            Rendered HTML template.

        Raises:
            TemplateNotFound: If response status code is 404.
            ValueError: In case of any other HTTP error (such as 403 or 500).
            RuntimeError: In case of any other error (such as ConnectionError).
        """
        response = self._get_render_response(template, context, accept='text/html')
        return response.text

    def get_template_info(self, template: Union[UUID, str]) -> dict:
        """
        Get template info.

        Args:
            template: Name of template or UUID.

        Returns:
            Template info (name, uuid, is_active, assets, ...).

        Raises:
            TemplateNotFound: If response status code is 404.
            ValueError: In case of any other HTTP error (such as 403 or 500).
            RuntimeError: In case of any other error (such as ConnectionError).
        """
        response = process_errors(requests.get)(
            self._get_template_url(template),
            timeout=self.timeout,
        )

        return response.json()

    def get_template_collections(self, tags: Sequence[str] = None) -> Sequence[str]:
        """
        Get template collections.

        Args:
            tags: Return only template collections with at least one of these tags.

        Returns:
            List of template collection names.
        """
        if not tags:
            tags = ['']

        collections = set()  # type: Set[str]
        for tag in tags:
            results = rest.get_all_results(
                urljoin(self.server_url, 'template-collections/'),
                params={'tags': tag},
                timeout=self.timeout,
            )
            collections |= set([col['name'] for col in results])

        return list(collections)

    def _get_template_url(self, template: Union[UUID, str]) -> str:
        """Get template url."""
        if isinstance(template, UUID):
            return urljoin(self.server_url, 'templates/{}/'.format(template))
        else:
            return urljoin(self.server_url, 'templates/active/{}/'.format(template))

    @process_errors
    def _get_render_response(self, template: Union[UUID, str], context: dict, *, accept: str) -> Response:
        """Render template."""
        response = requests.post(
            urljoin(self._get_template_url(template), 'render/'),
            headers={'Content-Type': 'application/json', 'Accept': accept},
            data=json.dumps({'context': context}),
            timeout=self.timeout,
        )

        return response

==> typist-0.4.0.tar.gz: typist-0.4.0/typist/client.py <==
"""Client for django-secretary."""
import json
from typing import Any, Callable, Sequence, Set, Tuple, Union, cast
from urllib.parse import urljoin
from uuid import UUID

import requests
from requests import HTTPError, RequestException, Response

from typist import rest


class TemplateNotFound(ValueError):
    """Template not found exception."""


def process_errors(func: Callable[..., Response]) -> Callable[..., Response]:
    """
    Process commonly raised connection errors.

    Args:
        func: Function returning the requests Response object.

    Raises:
        TemplateNotFound: If response status code is 404.
        ValueError: In case of any other HTTP error (such as 403 or 500).
        RuntimeError: In case of any other error (such as ConnectionError).
    """
    def wrapper(*args: Any, **kwargs: Any) -> Response:
        try:
            response = func(*args, **kwargs)
            if response.status_code == 404:
                raise TemplateNotFound('Template not found at url: {}'.format(response.request.url))
            response.raise_for_status()
        except HTTPError as error:
            if response.status_code >= 400 and response.status_code < 500:
                raise ValueError(str(error))
            else:
                raise RuntimeError(str(error))
        except RequestException as error:
            raise RuntimeError(str(error))

        return response

    return wrapper


class SecretaryClient:
    """Client for django-secretary."""

    def __init__(self, server_url: str, timeout: Union[float, Tuple[float, float]] = 3.05):
        """
        Initialize REST API client.

        Args:
            server_url: Server url of django-secretary app, including the path to the REST API with trailing slash.
            timeout: Timeout for the django-secretary API.
        """
        self.server_url = server_url
        self.timeout = timeout

    def render(self, template: Union[UUID, str], context: dict) -> str:
        """
        Render plaintext template.

        Args:
            template: Name of template or UUID.
            context: Context passed to template for rendering.

        Returns:
            Rendered plain text template.

        Raises:
            TemplateNotFound: If response status code is 404.
            ValueError: In case of any other HTTP error (such as 403 or 500).
            RuntimeError: In case of any other error (such as ConnectionError).
        """
        response = self._get_render_response(template, context, accept='text/plain')
        return response.text

    def render_html(self, template: Union[UUID, str], context: dict) -> str:
        """
        Render HTML template.

        Args:
            template: Name of template or UUID.
            context: Context passed to template for rendering.

        Returns:
            Rendered HTML template.

        Raises:
            TemplateNotFound: If response status code is 404.
            ValueError: In case of any other HTTP error (such as 403 or 500).
            RuntimeError: In case of any other error (such as ConnectionError).
        """
        response = self._get_render_response(template, context, accept='text/html')
        return response.text

    def render_pdf(self, template: Union[UUID, str], context: dict) -> bytes:
        """
        Render PDF template.

        Args:
            template: Name of template or UUID.
            context: Context passed to template for rendering.

        Returns:
            Rendered PDF.

        Raises:
            TemplateNotFound: If response status code is 404.
            ValueError: In case of any other HTTP error (such as 403 or 500).
            RuntimeError: In case of any other error (such as ConnectionError).
        """
        response = self._get_render_response(template, context, accept='application/pdf')
        return response.content

    def get_template_info(self, template: Union[UUID, str]) -> dict:
        """
        Get template info.

        Args:
            template: Name of template or UUID.

        Returns:
            Template info (name, uuid, is_active, assets, ...).

        Raises:
            TemplateNotFound: If response status code is 404.
            ValueError: In case of any other HTTP error (such as 403 or 500).
            RuntimeError: In case of any other error (such as ConnectionError).
        """
        response = process_errors(requests.get)(
            self._get_template_url(template),
            timeout=self.timeout,
        )

        return cast(dict, response.json())

    def get_template_collections(self, tags: Sequence[str] = None) -> Sequence[str]:
        """
        Get template collections.

        Args:
            tags: Return only template collections with at least one of these tags.

        Returns:
            List of template collection names.
        """
        if not tags:
            tags = ['']

        collections = set()  # type: Set[str]
        for tag in tags:
            results = rest.get_all_results(
                urljoin(self.server_url, 'template-collections/'),
                params={'tags': tag},
                timeout=self.timeout,
            )
            collections |= set([col['name'] for col in results])

        return list(collections)

    def _get_template_url(self, template: Union[UUID, str]) -> str:
        """Get template url."""
        if isinstance(template, UUID):
            return urljoin(self.server_url, 'templates/{}/'.format(template))
        else:
            return urljoin(self.server_url, 'templates/active/{}/'.format(template))

    @process_errors
    def _get_render_response(self, template: Union[UUID, str], context: dict, *, accept: str) -> Response:
        """Render template."""
        response = requests.post(
            urljoin(self._get_template_url(template), 'render/'),
            headers={'Content-Type': 'application/json', 'Accept': accept},
            data=json.dumps({'context': context}),
            timeout=self.timeout,
        )

        return response
